﻿using System.Web.Mvc;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.MvcEdition;
using System.Linq;

namespace CSharp_HowDoISamples
{
    public partial class BackgroundMapsController : Controller
    {
        public ActionResult DisplayASimpleMap()
        {
            Map map = new Map("Map1",
                new System.Web.UI.WebControls.Unit(100, System.Web.UI.WebControls.UnitType.Percentage),
                new System.Web.UI.WebControls.Unit(100, System.Web.UI.WebControls.UnitType.Percentage));

            map.MapUnit = GeographyUnit.DecimalDegree;
            map.CurrentExtent = new RectangleShape(-125, 72, 50, -46);

            EcwRasterLayer ecwImageLayer = new EcwRasterLayer(Server.MapPath(@"~\App_Data\World.ecw"));
            ecwImageLayer.UpperThreshold = double.MaxValue;
            ecwImageLayer.LowerThreshold = 0;

            LayerOverlay imageOverlay = new LayerOverlay("imageOverlay");
            imageOverlay.Layers.Add(ecwImageLayer);

            InMemoryFeatureLayer polygonShapeLayer = new InMemoryFeatureLayer();
            polygonShapeLayer.InternalFeatures.Add(new Feature("POLYGON((-132.74780273438 52.2509765625, -119.38842773438 25.5322265625, -61.732177734375 45.2197265625, -69.466552734375 52.2509765625, -132.74780273438 52.2509765625))"));
            polygonShapeLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(180, GeoColor.StandardColors.LightYellow));
            polygonShapeLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            imageOverlay.Layers.Add("polygon", polygonShapeLayer);

            map.MapBackground = new BackgroundLayer(new GeoSolidBrush(GeoColor.FromHtml("#E5E3DF")));
            map.CustomOverlays.Add(imageOverlay);

            return View(map);
        }

        [MapActionFilter]
        public void ClickEvent(Map map, GeoCollection<object> args)
        {
            PolygonShape worldPolygon = new RectangleShape(-181.26342773438, 97.9541015625, 189.98657226563, -93.2958984375).ToPolygon();

            Feature innnerFeature = ((map.CustomOverlays["imageOverlay"] as LayerOverlay).Layers["polygon"] as InMemoryFeatureLayer).InternalFeatures[0];
            if (innnerFeature.GetShape() is PolygonShape)
            {
                PolygonShape inner = innnerFeature.GetShape() as PolygonShape;
                worldPolygon.InnerRings.Add(new RingShape(inner.OuterRing.Vertices.Reverse()));
            }

            InMemoryFeatureLayer polygonLayer = (map.CustomOverlays["imageOverlay"] as LayerOverlay).Layers["polygon"] as InMemoryFeatureLayer;
            polygonLayer.InternalFeatures.Clear();
            polygonLayer.InternalFeatures.Add(new Feature(worldPolygon));

            polygonLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.StandardColors.White);
            polygonLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;


            var bitMap = map.GetBitmap();
            bitMap.Save("e:/b.png");
        }
    }
}